@@ -1,6 +1,7 @@
 from dotenv import dotenv_values
 from . import ncaablike
 from . import game
+from . import team
 from .. import sportsdataio_meta
 
 
@@ -8,6 +9,7 @@ from .. import sportsdataio_meta
 class Ncaab(ncaablike.NCAABlike):
 
     games : game.gameslike.Gameslike
+    teams : team.teamlike.TeamsByIdlike
     
     def __init__(self) -> None:
 
@@ -16,4 +18,5 @@ class Ncaab(ncaablike.NCAABlike):
             "SPORTS_DATA_DOMAIN"
         )
         self.games = game.games.Games(meta)
+        self.teams = team.team.TeamsById(meta)
 
